@@ -1,4 +1,4 @@
-from ctextinct.controller import Controller, Model
+from ctextinct.controller import Controller
 import argparse
 
 trainUpdate = argparse.ArgumentParser(description="Train specific file")
